@@ -50,9 +50,9 @@ from .stubs import (
     FakeSignerVerify,
 )
 from .test_registryv2 import (
-    credentials_store_path,
-    image_name,
-    replicate_manifest_lists,
+    credentials_store_path,  # Needed for pytest
+    image_name,  # Needed for pytest
+    replicate_manifest_lists,  # Needed for pytest
 )
 
 pytestmark = [pytest.mark.asyncio, *_pytestmark]
@@ -153,9 +153,11 @@ async def test__verify_image_config(
     )
 
     # Sign
-    image_name_dest = known_good_image_proxy.image_name.clone()
-    image_name_dest.digest = None
-    image_name_dest.tag = test__verify_image_config.__name__
+    image_name_dest = (
+        known_good_image_proxy.image_name.clone()
+        .set_digest()
+        .set_tag(test__verify_image_config.__name__)
+    )
     await registry_v2_image_source_proxy.sign_image(
         image_name_dest=image_name_dest,
         image_name_src=known_good_image_proxy.image_name,
@@ -323,9 +325,8 @@ async def test_sign_image_same_image_source(
     known_good_image_proxy: TypingKnownGoodImage,
 ):
     """Test image signing."""
-    dest_image_name = known_good_image_proxy.image_name.clone()
-    dest_image_name.digest = None
-    dest_image_name.tag = f"{dest_image_name.tag}_signed"
+    dest_image_name = known_good_image_proxy.image_name.clone().set_digest()
+    dest_image_name.tag += "_signed"
 
     def assertions(result: RegistryV2SignImage):
         assert result
@@ -418,9 +419,11 @@ async def test_verify_image_signatures(
     assert str(exception.value) == "Image does not contain any signatures!"
 
     # Sign
-    image_name_dest = known_good_image_proxy.image_name.clone()
-    image_name_dest.digest = None
-    image_name_dest.tag = test_verify_image_signatures.__name__
+    image_name_dest = (
+        known_good_image_proxy.image_name.clone()
+        .set_digest()
+        .set_tag(test_verify_image_signatures.__name__)
+    )
     await registry_v2_image_source_proxy.sign_image(
         image_name_dest=image_name_dest,
         image_name_src=known_good_image_proxy.image_name,
